pub enum AppTheme {
Show 14 variants
Default,
MidnightGreen,
IAmBlue,
SolarizedDark,
Greyscale,
Nord,
Dracula,
Monokai,
Gruvbox,
TokyoNight,
CatppuccinMocha,
OneDark,
AyuDark,
USA,
}Variants
Default
Default theme.
MidnightGreen
Dark theme with green text.
IAmBlue
IAmBlue
SolarizedDark
Solarized Dark theme
Greyscale
Greyscale theme
Nord
Nord theme
Dracula
Dracula theme
Monokai
Monokai theme
Gruvbox
Gruvbox theme
TokyoNight
Tokyo Night theme
CatppuccinMocha
Catppuccin Mocha theme
OneDark
One Dark theme
AyuDark
Ayu Dark theme
USA
USA theme with American colors
Implementations
Sourceimpl AppTheme
impl AppTheme
Sourcepub fn text_color(&self) -> Color
pub fn text_color(&self) -> Color
Returns the default text color for the theme.
Sourcepub fn title_style(&self) -> Style
pub fn title_style(&self) -> Style
Returns the title text color for the theme.
Sourcepub fn border_style(&self) -> Style
pub fn border_style(&self) -> Style
Returns the border color for the theme.
Sourcepub fn text_enabled_color(&self) -> Color
pub fn text_enabled_color(&self) -> Color
Returns the default text enabled color for the theme.
Sourcepub fn text_disabled_color(&self) -> Color
pub fn text_disabled_color(&self) -> Color
Returns the default text disabled color for the theme.
Sourcepub fn text_important_color(&self) -> Color
pub fn text_important_color(&self) -> Color
Returns the default text important color for the theme.
Sourcepub fn sparkline_style(&self) -> Style
pub fn sparkline_style(&self) -> Style
Returns the sparkline style for the theme.
Sourcepub fn kernel_symbol_color(&self) -> Color
pub fn kernel_symbol_color(&self) -> Color
Returns the color for kernel space symbols in perf top view.
Sourcepub fn userspace_symbol_color(&self) -> Color
pub fn userspace_symbol_color(&self) -> Color
Returns the color for userspace symbols in perf top view.
Sourcepub fn plot_marker(&self) -> Marker
pub fn plot_marker(&self) -> Marker
Returns the plot marker for charts in the theme.
Sourcepub fn positive_value_color(&self) -> Color
pub fn positive_value_color(&self) -> Color
Returns the color for positive values (e.g., TX data) in the theme.
Sourcepub fn negative_value_color(&self) -> Color
pub fn negative_value_color(&self) -> Color
Returns the color for negative values (e.g., RX data) in the theme.
Sourcepub fn gradient_3_low(&self, reverse: bool) -> Color
pub fn gradient_3_low(&self, reverse: bool) -> Color
Returns the low-level color for a 3-level gradient.
Arguments
reverse- If true, high values get the “good” color, if false, low values get the “good” color
Sourcepub fn gradient_3_mid(&self) -> Color
pub fn gradient_3_mid(&self) -> Color
Returns the mid-level color for a 3-level gradient. Mid-level always uses the important/warning color regardless of reverse direction.
Sourcepub fn gradient_3_high(&self, reverse: bool) -> Color
pub fn gradient_3_high(&self, reverse: bool) -> Color
Returns the high-level color for a 3-level gradient.
Arguments
reverse- If true, high values get the “good” color, if false, low values get the “good” color
Sourcepub fn gradient_3(
&self,
value: f64,
low_threshold: f64,
high_threshold: f64,
reverse: bool,
) -> Color
pub fn gradient_3( &self, value: f64, low_threshold: f64, high_threshold: f64, reverse: bool, ) -> Color
Returns a color for a 3-level gradient (LOW, MID, HIGH) based on value and thresholds.
Arguments
value- The current value to evaluatelow_threshold- Values <= this are considered LOWhigh_threshold- Values >= this are considered HIGHreverse- If true, high values get the “good” color (green), if false, low values get the “good” color
Sourcepub fn gradient_5(
&self,
value: f64,
very_low_threshold: f64,
low_threshold: f64,
high_threshold: f64,
very_high_threshold: f64,
reverse: bool,
) -> Color
pub fn gradient_5( &self, value: f64, very_low_threshold: f64, low_threshold: f64, high_threshold: f64, very_high_threshold: f64, reverse: bool, ) -> Color
Returns a color for a 5-level gradient (VERY_LOW, LOW, MID, HIGH, VERY_HIGH) based on value and thresholds.
Arguments
value- The current value to evaluatevery_low_threshold- Values <= this are considered VERY_LOWlow_threshold- Values <= this (but > very_low) are considered LOWhigh_threshold- Values >= this (but < very_high) are considered HIGHvery_high_threshold- Values >= this are considered VERY_HIGHreverse- If true, high values get the “good” color, if false, low values get the “good” color